/***********************************************************************/
/* Sistemas Integrados TECNISA                                         */
/*                                                                     */
/* Pedidos, Expedio                                                  */
/*                                                                     */
/***********************************************************************/
/*                                                                     */
/* Nome: 2850_PEDSTP_CONSISTE_PEDIDO                                   */
/*                                                                     */
/* Descrio:                                                          */
/*     Est procedure faz a consistencia do pedido. Ela  definida     */
/* pelo cliente. Ele pede para incluir um registro na tabela CONSPEDIDO*/
/* e define a forma como o sistema deve fazer a consistencia.          */
/*                                                                     */
/* Criao:                                                            */
/* 25/09/2003 - Andr Rodrigo                                          */
/*                                                                     */
/*                                                                     */
/* @C:\WIN_PRJ\SQL\END_CONV\ORACLE\2850_PEDSTP_CONSISTE_PEDIDO.SQL     */
/*                                                                     */
/* raise_application_error(-20501, :OLD.CDFILIAL||'-'||:OLD.NRPEDIDO||'-'||:OLD.NRITEMPED, True); */
/***********************************************************************/

IF EXISTS (SELECT *
           FROM SYSOBJECTS O, SYSUSERS U
           WHERE O.NAME = 'GRAVA_INCONSPEDIDO' AND
	         TYPE = 'P' 		       AND
      	         U.UID = O.UID                 AND
      	         U.NAME = USER)
DROP PROCEDURE GRAVA_INCONSPEDIDO
GO
CREATE PROCEDURE GRAVA_INCONSPEDIDO @P_CDFILIAL     VARCHAR(4),
                                    @P_NRPEDIDO     VARCHAR(10),
                                    @P_NRITEMPED    VARCHAR(10),
                                    @P_CDCONSPEDIDO VARCHAR(3),
                                    @P_IDINCONSLIB  VARCHAR(1) OUTPUT
AS
   DECLARE @V_NRINCONSPED   VARCHAR(3);
   DECLARE @V_CTINCONS      INTEGER;
   DECLARE @V_CTCONSLIB     INTEGER;
BEGIN
   /* Verifica se j existe a inconsistcia no item do pedido */
   SELECT @V_CTINCONS = COUNT(*)
   FROM INCONSPEDIDO
   WHERE (CDFILIAL     = @P_CDFILIAL)
     AND (NRPEDIDO     = @P_NRPEDIDO)
     AND (NRITEMPED    = @P_NRITEMPED OR @P_NRITEMPED IS NULL)
     AND (CDCONSPEDIDO = @P_CDCONSPEDIDO);

   SET @P_IDINCONSLIB = 'E';
   IF @V_CTINCONS = 0 BEGIN
      SELECT @V_NRINCONSPED = ISNULL(MAX(NRINCONSPED), 0) + 1
      FROM INCONSPEDIDO
      WHERE CDFILIAL = @P_CDFILIAL
        AND NRPEDIDO = @P_NRPEDIDO;

      INSERT INTO INCONSPEDIDO
         (CDFILIAL, NRPEDIDO, NRINCONSPED,
          NRITEMPED, CDCONSPEDIDO)
      VALUES
         (@P_CDFILIAL, @P_NRPEDIDO, RIGHT(REPLICATE('0', 3) + CAST(@V_NRINCONSPED AS VARCHAR), 3),
          @P_NRITEMPED, @P_CDCONSPEDIDO);

      SET @P_IDINCONSLIB = 'E';
   END
   ELSE BEGIN
      /* Verifica se a inconsistcia j foi liberada */
      SELECT @V_CTCONSLIB = COUNT(*)
      FROM INCONSPEDIDO
      WHERE (CDFILIAL     = @P_CDFILIAL)
        AND (NRPEDIDO     = @P_NRPEDIDO)
        AND (NRITEMPED    = @P_NRITEMPED OR @P_NRITEMPED IS NULL)
        AND (CDCONSPEDIDO = @P_CDCONSPEDIDO)
        AND (DTLIBEINCONS IS NOT NULL);

      IF @V_CTCONSLIB > 0 BEGIN
         SET @P_IDINCONSLIB = 'L';
      END;
   END;
END;
GO

-- VERSAO --
EXEC ATUVEROBJ 'GRAVA_INCONSPEDIDO','4.05.126';
GO

